.. _index:

Welcome to pyckmeans' documentation!
====================================

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    installation.rst
    documentation.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
